function [Feats, nMeanSeg] = m_cmpSegFeats_1D(metaD, binW, posOrNeg, shldDsp)
% Do segmentation and compute feature.
% Inputs:
%   metaD: a structure with the required fields:
%       PosD: a cell structure containing positive signals
%       NegD: a cell structure containing negative signals
%       nSeg: number of foreground segments allowed
%       nBin: number of histogram bin = # of dimension of the SVM weight vector.
%   binW: the SVM weight vector, this is a column vector
%   posOrNeg: must be either 'pos' or 'neg'
% Outputs:
%   Feats: nBin*n matrix, where n is the number of positive or negative signals
%       depending on posOrNeg option.
%   nMeanSeg: number of average foreground segments
% By: Minh Hoai Nguyen (minhhoai@gmail.com)
% Last modified: 3 Oct 2010

if ~exist('shldDsp', 'var') || isempty(shldDsp)
    shldDsp = 0;
end;

if strcmpi(posOrNeg, 'pos')
    Signals = metaD.PosD;
elseif strcmp(posOrNeg, 'neg')
    Signals = metaD.NegD;
else
    error('m_cmpSegFeats_1D: unrecognized option');
end;

nSeg = metaD.nSeg;
nBin = length(binW);

Feats = zeros(nBin, length(Signals));
nMeanSeg = 0;
if ~exist('shldDsp', 'var')
    shldDsp = 0;
end;
if shldDsp          
    [dc, machineName] = system('uname -n');
    figure('Name', machineName);
    nR = ceil(sqrt(length(Signals)));
    nC = nR;
end
for i=1:length(Signals)
    %signal = [1:length(Signals{i}); Signals{i}]';
    signal = Signals{i};
    signalL = max(signal(:,1)); % length of signal
    
    Segs = ml_findMulti1DSegs(signal, signalL, -binW, nSeg);
    
    nMeanSeg = nMeanSeg + size(Segs,2);

    fgIdxs = zeros(signalL, 1); % indexes for parts in the foreground
    for j=1:size(Segs,2)
        fgIdxs(Segs(1,j):Segs(2,j)) = 1;
    end;
    fgIdxs = logical(fgIdxs);
    histo = hist(signal(fgIdxs(signal(:,1)),2), 1:nBin);
    Feats(:,i) = histo(:); 
    
    % normalize by singal length
    Feats(:,i) = Feats(:,i)/signalL;
    
    if shldDsp        
        im = 255*ones(length(binW), signalL);
        im(sub2ind(size(im), signal(:,2), signal(:,1))) = 0;
        subplot(nR, nC, i); 
        imshow(im); 
        fprintf('No of segments: %d\n', size(Segs,2));
        for j = 1:size(Segs,2)
            line([Segs(1,j); Segs(1,j)], [1;length(binW)], 'Color', 'red');
            line([Segs(2,j); Segs(2,j)], [1;length(binW)], 'Color', 'blue');            
        end;
    end;
end;
nMeanSeg = nMeanSeg/size(Feats,2);
