function [Ws, objVals, wDeviations, AllWs] = m_learnSegMCSVM(metaD)
% function [w, b, objVals, wDeviation] = m_learnSegMCSVM(metaD)
%   Learn segmentation SVM.
% Inputs:
%   metaD is a structure which requires the fields:
%       C: C of C-SVM
%       nClass: # of classes
%       nBin: # of dimension of feature vector (# of histogram bins)
%       lb: label vector for training data
%       runID: # any string that you want to be printed during the optimization.
%       cmpInitFeats: the name of function to compute initial features.
%       cmpSegFeats: the name of the function to do segmentation and compute features.
% Outputs:
%   Ws: nBin*nClass weight matrix
%   objVals: objective values as a function of iterations
%   wDeviation: deviation of w as function of iterations.
%   AllWs: cell structure, store all Ws as the number of iterations increases.
% By: Minh Hoai Nguyen (minhhoai@gmail.com)
% Date: 7 July 2011.

if ~isfield(metaD, 'C')
    error('m_learnSegMCSVM: metaD.C is not defined');
elseif ~isfield(metaD, 'nClass')
    error('m_learnSegMCSVM: metaD.nClass is not defined');
elseif ~isfield(metaD, 'lb')
    error('m_learnSegMCSVM: metaD.lb is not defined');
elseif ~isfield(metaD, 'cmpInitFeats')
    error('m_learnSegMCSVM: metaD.cmpInitFeats is not defined');    
elseif ~isfield(metaD, 'cmpSegFeats')
    error('m_learnSegMCSVM: metaD.cmpSegFeats is not defined');
end;

if ~isfield(metaD, 'runID')
    metaD.runID = '';
end    

[Ws, objVals, wDeviations, AllWs] = m_mexLearnSegMCSVM(metaD);

