function [w, b, objVals, wDeviation] = m_learnSegSVM(metaD)
% function [w, b, objVals, wDeviation] = m_learnSegSVM(metaD)
%   Learn segmentation SVM.
% Inputs:
%   metaD is a structure which requires the fields:
%       C: C of C-SVM
%       nNeg: # of negative signals
%       nPos: # of positive signals
%       nBin: # of dimension of feature vector (# of histogram bins)
%       runID: # any string that you want to be printed during the optimization.
%       cmpInitFeats: the name of function to compute initial features.
%       cmpSegFeats: the name of the function to do segmentation and compute features.
% Outputs:
%   w: nBin*1 column vector for the weight
%   b: scalar offset
%   objVals: objective values as a function of iterations
%   wDeviation: deviation of w as function of iterations.
% By: Minh Hoai Nguyen (minhhoai@gmail.com)
% Date: 3 Sep 2010.

if ~isfield(metaD, 'C')
    error('m_learnSegSVM: metaD.C is not defined');
elseif ~isfield(metaD, 'nNeg')
    error('m_learnSegSVM: metaD.nNeg is not defined');
elseif ~isfield(metaD, 'nPos')
    error('m_learnSegSVM: metaD.nPos is not defined');
elseif ~isfield(metaD, 'cmpInitFeats')
    error('m_learnSegSVM: metaD.cmpInitFeats is not defined');    
elseif ~isfield(metaD, 'cmpSegFeats')
    error('m_learnSegSVM: metaD.cmpSegFeats is not defined');
end;

if ~isfield(metaD, 'runID')
    metaD.runID = '';
end    

[w, b, objVals, wDeviation] = m_mexLearnSegSVM(metaD); 