function m_main_kitchen_MC(nSeg)
% Exp. on CMU kitchen accelerometer data, classifying what recipe is being cooked. 
% This is the multi-class version.
% Inputs:
%   nSeg: number of segments for foreground extraction
% Minh Hoai Nguyen
% Date: 25 Apr 2011
% By Minh Hoai Nguyen

if ~exist('nSeg', 'var')
    nSeg = 5;
end

try 
    addpath('/Users/hoai/Study/Projects/SegMMC/bin/');
catch e    
end;

winSz = 1000;
nBin = 50;

%dataDir = '/Users/hoai/DataSets/CMUKitchen/FiveWiredIMUs/';
dataDir = '../data/';
load(sprintf('%s/BaoIntille_winSz%d_nBin%d.mat', dataDir, winSz, nBin), 'DClust');
recipes = {'Brownie', 'Eggs', 'Pizza', 'Salad', 'Sandwich'};

nClass = length(recipes);
trLbs = cell(1, nClass);
for i=1:nClass
    trLbs{i} = i*ones(1, numel(DClust(i).trTSs));
end;
trLb = cat(2, trLbs{:});
TrD = cat(2, DClust(:).trTSs);

tstLbs = cell(1, nClass);
for i=1:nClass
    tstLbs{i} = i*ones(1, numel(DClust(i).tstTSs));
end;
tstLb = cat(2, tstLbs{:});
TstD = cat(2, DClust(:).tstTSs);

trMetaD.C = 100;
trMetaD.nBin = nBin;
trMetaD.nClass = nClass;
trMetaD.nSeg = nSeg;
trMetaD.cmpInitFeats = 'm_cmpInitFeats_1D_MC';
trMetaD.cmpSegFeats  = 'm_cmpSegFeats_1D_MC';
trMetaD.runID = 'kitchen_MC';

% Do classification using global statistics
trMetaD.initOption_pos = 'Global';
trMetaD.initOption_neg = 'Global';
trMetaD.D = TrD;
trMetaD.lb = trLb;
trMetaD.nSample = size(trMetaD.D,2);
TrGlobFeats  = m_cmpInitFeats_1D_MC(trMetaD, 'pos'); 
Ws = m_mexMCSVM(TrGlobFeats, trMetaD.nClass, trMetaD.C, trLb);


tstMetaD   = trMetaD;
tstMetaD.D = TstD;
tstMetaD.lb = [];
tstMetaD.nSample = size(TstD, 2); 


TrFeats_glob = m_cmpInitFeats_1D_MC(trMetaD, 'pos'); 
TrSVMScores_glob = Ws'*TrFeats_glob;
[dc, predLb_tr_glob] = max(TrSVMScores_glob, [], 1);
[ConfMat_tr_glob, acc_tr_glob] = m_getConfMat(nClass, trLb, predLb_tr_glob); 

TstFeats_glob = m_cmpInitFeats_1D_MC(tstMetaD, 'pos'); 
TstSVMScores_glob = Ws'*TstFeats_glob;
[dc, predLb_tst_glob] = max(TstSVMScores_glob, [], 1);
[ConfMat_tst_glob, acc_tst_glob] = m_getConfMat(nClass, tstLb, predLb_tst_glob); 


trMetaD.initOption_pos = 'random';
trMetaD.initOption_neg = 'random';
trMetaD.initW = Ws;
[Ws_seg, objVals, wDeviations, AllWs] = m_mexLearnSegMCSVM(trMetaD);

[TrFeats_seg, predLb_tr_seg] = m_cmpSegFeats_1D_MC(trMetaD, Ws_seg, 'test');
[ConfMat_tr_seg, acc_tr_seg] = m_getConfMat(nClass, trLb, predLb_tr_seg);

[TstFeats_seg, predLb_tst_seg] = m_cmpSegFeats_1D_MC(tstMetaD, Ws_seg, 'test');
[ConfMat_tst_seg, acc_tst_seg] = m_getConfMat(nClass, tstLb, predLb_tst_seg);

fprintf('Global_train, mean acc: %g, confusion matrix:\n', acc_tr_glob); disp(ConfMat_tr_glob);
fprintf('SegSVM_train, mean acc: %g, confusion matrix:\n', acc_tr_seg); disp(ConfMat_tr_seg);
fprintf('Global_tst, mean acc: %g, confusion matrix:\n', acc_tst_glob); disp(ConfMat_tst_glob);
fprintf('SegSVM_tst, mean acc: %g, confusion matrix:\n', acc_tst_seg); disp(ConfMat_tst_seg);

fprintf('How energy and acc. evolve as the # of iters increases\n');
for i=1:length(AllWs)
    [TrFeats_seg, predLb_tr_seg] = m_cmpSegFeats_1D_MC(trMetaD, AllWs{i}, 'test');
    [ConfMat_tr_seg, acc_tr_seg] = m_getConfMat(nClass, trLb, predLb_tr_seg);
    
    [TstFeats_seg, predLb_tst_seg] = m_cmpSegFeats_1D_MC(tstMetaD, AllWs{i}, 'test');
    [ConfMat_tst_seg, acc_tst_seg] = m_getConfMat(nClass, tstLb, predLb_tst_seg);
    fprintf('%2d, energy: %10.6f, test acc: %.4f, tr acc: %.4f\n', ...
        i, objVals{i}(end), acc_tst_seg, acc_tr_seg); %disp(ConfMat_tst_seg);
end;
