function m_main_synData1D(nSeg)
% Run experiment on 1D synthetic data. 
% This is for the binary case: positve and negative are asymmetric.
% Inputs:
%   nSeg: maximum number of sub-segments to be considered.
% By Minh Hoai Nguyen (minhhoai@gmail.com)
% Last modified: 7 July 2011

if ~exist('nSeg', 'var')
    nSeg2 = 3;
else
    nSeg2 = nSeg;
end

load ../data/synData1D.mat;
TrPosIms = vectors2Cell(TrPosD);
TrNegIms = vectors2Cell(TrNegD);
TstPosIms = vectors2Cell(TstPosD);
TstNegIms = vectors2Cell(TstNegD);

metaD.C = 0.01;
metaD.nNeg = length(TrNegIms);
metaD.nPos = length(TrPosIms);
metaD.nBin = 2;
metaD.nSeg = nSeg2;
metaD.cmpInitFeats = 'm_cmpInitFeats_1D';
metaD.cmpSegFeats = 'm_cmpSegFeats_1D';
metaD.useBias = 0;
metaD.runID = '1DsynData';

% Do classification using global statistics
metaD.initOption_pos = 'Global';
metaD.initOption_neg = 'Global';
metaD.PosD = TrPosIms;
metaD.NegD = TrNegIms;
PosTrFeats  = m_cmpInitFeats_1D(metaD, 'pos'); 
NegTrFeats  = m_cmpInitFeats_1D(metaD, 'neg'); 

metaD.PosD = TstPosIms;
metaD.NegD = TstNegIms;
PosTstFeats = m_cmpInitFeats_1D(metaD, 'pos'); 
NegTstFeats = m_cmpInitFeats_1D(metaD, 'neg'); 

nPosTr = size(TrPosD, 2);
nNegTr = size(TrNegD, 2);

opts = sprintf('-t 0 -c %g -w1 %g -w-1 %g', metaD.C, 1/nPosTr, 1/nNegTr);
TrD  = [PosTrFeats, NegTrFeats];
TrL  = [ones(nPosTr,1); -ones(nNegTr,1)];
model = svmtrain(TrL, TrD', opts); 
initW = full(model.SVs)'*model.sv_coef;
initB = -model.rho;


x = initW'*NegTrFeats + initB;
y = initW'*PosTrFeats + initB;
[rocArea_tr_glob, thres, acc_tr_glob] = ml_roc(x, y, 0);

x = initW'*NegTstFeats + initB;
y = initW'*PosTstFeats + initB;
[rocArea_tst_glob, thres, acc_tst_glob] = ml_roc(x, y, 0);


% Running SegSVM
metaD.PosD = TrPosIms;
metaD.NegD = TrNegIms;
metaD.initOption_pos = 'initW';
metaD.initOption_neg = 'random';
metaD.initW = initW;
[binW, b] = m_mexLearnSegSVM(metaD); % learn the weights

fprintf('Glob:   train data, rocArea: %g, acc: %g\n', rocArea_tr_glob, acc_tr_glob);  
fprintf('Glob:   test  data, rocArea: %g, acc: %g\n', rocArea_tst_glob, acc_tst_glob);  

% Use the learned weights
Feats = m_cmpSegFeats_1D(metaD, binW, 'pos'); 
y = binW(:)'*Feats + b;
Feats = m_cmpSegFeats_1D(metaD, binW, 'neg'); 
x = binW(:)'*Feats + b;
[rocArea, thres, acc] = ml_roc(x, y, 0);
fprintf('SegSVM: train data, rocArea: %g, acc: %g\n', rocArea, acc);    

metaD.PosD = TstPosIms;
metaD.NegD = TstNegIms;
Feats = m_cmpSegFeats_1D(metaD, binW, 'pos'); 
y = binW(:)'*Feats + b;
Feats = m_cmpSegFeats_1D(metaD, binW, 'neg'); 
x = binW(:)'*Feats + b;
[rocArea, thres, acc] = ml_roc(x, y, 0);
fprintf('SegSVM: test  data, rocArea: %g, acc: %g\n', rocArea, acc);    


function Dcell = vectors2Cell(D)
% helper function
    Dcell = cell(1, size(D,2));
    for i=1:size(D,2)
        Dcell{i} = [(1:size(D,1))', D(:,i)];    
    end;

function plotSignal(signal)
    stairs(signal - 1, 'LineWidth', 2); axis([-1 (length(signal)+2) -0.3 1.3]);

