/*
 * m_utils.cpp
 *
 * Created on: Jul 29, 2009
 * Author: Minh Hoai Nguyen, Carnegie Mellon University
 * Email:  minhhoai@cmu.edu, minhhoai@gmail.com
 */

#include "m_utils.h"
#include <math.h>
#include <gsl/gsl_cblas.h>


double diffclock(clock_t clock1,clock_t clock2)
{
   double diffticks=clock1-clock2;
   double diffms= diffticks/CLOCKS_PER_SEC;
   return diffms;
}


bool isDeviateEnough(IloNumArray newVec, double *oldVec, double *deviation){
   double TOL_FACTOR = 0.001;
   int n = newVec.getSize();
   double diff_L1 = 0;
   double oldVec_L1 = 0;
   for (int i= 0; i < n; i++){
      diff_L1   += fabs(newVec[i] - oldVec[i]);
      oldVec_L1 += fabs(oldVec[i]);
   }
   deviation[0] = diff_L1;
   return (diff_L1 > TOL_FACTOR*oldVec_L1);
}

/* calculate svmVals= Feats'*w + b;
 * Feat is a nBin*n matrix
 * w is nBin*1 vector
 */
double *cmpSVMVals(double *Feat, int n, int nBin,  double *w, IloNum b)
{
//   double *svmVals = (double*)(mxCalloc(n, sizeof (double)));
   double *svmVals = new double[n];
   for(int i = 0;i < n;i++){
      svmVals[i] = b;
   }
   cblas_dgemv(CblasColMajor, CblasTrans, nBin, n, 1.0, Feat, nBin, w, 1, 1.0, svmVals, 1);
   return svmVals;
}

void cmpMCSVMVals(double const *Feat, int const *classIdxs, double const *w,
      int n, int nBin, double *svmVals){
   for (int i=0; i < n; i++){
      svmVals[i] = cblas_ddot(nBin, Feat + i*nBin, 1, w + classIdxs[i]*nBin, 1);
   }
}
